PAWpySeed: pawpyseed.analysis.run_pawpy.DummyFirework Class Reference

PAWpySeed Parallel C/Python package for numerical analysis of PAW DFT wavefunctions

- Main Page
- Classes
- Files

- Class List
- Class Index
- Class Hierarchy
- Class Members

Public Member Functions | Public Attributes | List of all members
pawpyseed.analysis.run_pawpy.DummyFirework Class Reference

## Public Member Functions
def | __init__ (self, path)

## Public Attributes
| launches
| name
| fw_id

## Constructor & Destructor Documentation

def pawpyseed.analysis.run_pawpy.DummyFirework.__init__ | ( |  | self,
|  |  | path
| ) |  |

## Member Data Documentation

pawpyseed.analysis.run_pawpy.DummyFirework.fw_id

pawpyseed.analysis.run_pawpy.DummyFirework.launches

pawpyseed.analysis.run_pawpy.DummyFirework.name

The documentation for this class was generated from the following file:

- /home/kyle/Research/projects/pawpyseed/pawpyseed/analysis/run_pawpy.py